==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/DomainRegistrant.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "countryOrRegionCode", 
    "organization", 
    "url", 
    "vendor"})
@JsonInclude(Include.NON_NULL)
public class DomainRegistrant implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("countryOrRegionCode")
    protected String countryOrRegionCode;

    @JsonProperty("organization")
    protected String organization;

    @JsonProperty("url")
    protected String url;

    @JsonProperty("vendor")
    protected String vendor;

    protected DomainRegistrant() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.domainRegistrant";
    }

    @Property(name="countryOrRegionCode")
    @JsonIgnore
    public Optional<String> getCountryOrRegionCode() {
        return Optional.ofNullable(countryOrRegionCode);
    }

    public DomainRegistrant withCountryOrRegionCode(String countryOrRegionCode) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.countryOrRegionCode = countryOrRegionCode;
        return _x;
    }

    @Property(name="organization")
    @JsonIgnore
    public Optional<String> getOrganization() {
        return Optional.ofNullable(organization);
    }

    public DomainRegistrant withOrganization(String organization) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.organization = organization;
        return _x;
    }

    @Property(name="url")
    @JsonIgnore
    public Optional<String> getUrl() {
        return Optional.ofNullable(url);
    }

    public DomainRegistrant withUrl(String url) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.url = url;
        return _x;
    }

    @Property(name="vendor")
    @JsonIgnore
    public Optional<String> getVendor() {
        return Optional.ofNullable(vendor);
    }

    public DomainRegistrant withVendor(String vendor) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.vendor = vendor;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String countryOrRegionCode;
        private String organization;
        private String url;
        private String vendor;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder countryOrRegionCode(String countryOrRegionCode) {
            this.countryOrRegionCode = countryOrRegionCode;
            this.changedFields = changedFields.add("countryOrRegionCode");
            return this;
        }

        public Builder organization(String organization) {
            this.organization = organization;
            this.changedFields = changedFields.add("organization");
            return this;
        }

        public Builder url(String url) {
            this.url = url;
            this.changedFields = changedFields.add("url");
            return this;
        }

        public Builder vendor(String vendor) {
            this.vendor = vendor;
            this.changedFields = changedFields.add("vendor");
            return this;
        }

        public DomainRegistrant build() {
            DomainRegistrant _x = new DomainRegistrant();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.domainRegistrant";
            _x.countryOrRegionCode = countryOrRegionCode;
            _x.organization = organization;
            _x.url = url;
            _x.vendor = vendor;
            return _x;
        }
    }

    private DomainRegistrant _copy() {
        DomainRegistrant _x = new DomainRegistrant();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.countryOrRegionCode = countryOrRegionCode;
        _x.organization = organization;
        _x.url = url;
        _x.vendor = vendor;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("DomainRegistrant[");
        b.append("countryOrRegionCode=");
        b.append(this.countryOrRegionCode);
        b.append(", ");
        b.append("organization=");
        b.append(this.organization);
        b.append(", ");
        b.append("url=");
        b.append(this.url);
        b.append(", ");
        b.append("vendor=");
        b.append(this.vendor);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/DomainRegistrant.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "countryOrRegionCode", 
    "organization", 
    "url", 
    "vendor"})
@JsonInclude(Include.NON_NULL)
public class DomainRegistrant implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("countryOrRegionCode")
    protected String countryOrRegionCode;

    @JsonProperty("organization")
    protected String organization;

    @JsonProperty("url")
    protected String url;

    @JsonProperty("vendor")
    protected String vendor;

    protected DomainRegistrant() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.domainRegistrant";
    }

    @Property(name="countryOrRegionCode")
    @JsonIgnore
    public Optional<String> getCountryOrRegionCode() {
        return Optional.ofNullable(countryOrRegionCode);
    }

    public DomainRegistrant withCountryOrRegionCode(String countryOrRegionCode) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.countryOrRegionCode = countryOrRegionCode;
        return _x;
    }

    @Property(name="organization")
    @JsonIgnore
    public Optional<String> getOrganization() {
        return Optional.ofNullable(organization);
    }

    public DomainRegistrant withOrganization(String organization) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.organization = organization;
        return _x;
    }

    @Property(name="url")
    @JsonIgnore
    public Optional<String> getUrl() {
        return Optional.ofNullable(url);
    }

    public DomainRegistrant withUrl(String url) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.url = url;
        return _x;
    }

    @Property(name="vendor")
    @JsonIgnore
    public Optional<String> getVendor() {
        return Optional.ofNullable(vendor);
    }

    public DomainRegistrant withVendor(String vendor) {
        DomainRegistrant _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainRegistrant");
        _x.vendor = vendor;
        return _x;
    }

    public DomainRegistrant withUnmappedField(String name, Object value) {
        DomainRegistrant _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String countryOrRegionCode;
        private String organization;
        private String url;
        private String vendor;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder countryOrRegionCode(String countryOrRegionCode) {
            this.countryOrRegionCode = countryOrRegionCode;
            this.changedFields = changedFields.add("countryOrRegionCode");
            return this;
        }

        public Builder organization(String organization) {
            this.organization = organization;
            this.changedFields = changedFields.add("organization");
            return this;
        }

        public Builder url(String url) {
            this.url = url;
            this.changedFields = changedFields.add("url");
            return this;
        }

        public Builder vendor(String vendor) {
            this.vendor = vendor;
            this.changedFields = changedFields.add("vendor");
            return this;
        }

        public DomainRegistrant build() {
            DomainRegistrant _x = new DomainRegistrant();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.domainRegistrant";
            _x.countryOrRegionCode = countryOrRegionCode;
            _x.organization = organization;
            _x.url = url;
            _x.vendor = vendor;
            return _x;
        }
    }

    private DomainRegistrant _copy() {
        DomainRegistrant _x = new DomainRegistrant();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.countryOrRegionCode = countryOrRegionCode;
        _x.organization = organization;
        _x.url = url;
        _x.vendor = vendor;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("DomainRegistrant[");
        b.append("countryOrRegionCode=");
        b.append(this.countryOrRegionCode);
        b.append(", ");
        b.append("organization=");
        b.append(this.organization);
        b.append(", ");
        b.append("url=");
        b.append(this.url);
        b.append(", ");
        b.append("vendor=");
        b.append(this.vendor);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
